#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class SectioningSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         SectioningSettingAtt
                | 
                | The interface to access a CATIASectioningSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sectioning_setting_att = com_object

    @property
    def clipping_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ClippingMode() As CatSectionClippingMode
                | 
                |     Returns or sets the ClippingMode parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: int
        :rtype: int
        """

        return self.sectioning_setting_att.ClippingMode

    @clipping_mode.setter
    def clipping_mode(self, value: int):
        """
        :param int value:
        """

        self.sectioning_setting_att.ClippingMode = value

    @property
    def display_cut_in_wireframe(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DisplayCutInWireframe() As boolean
                | 
                |     Returns or sets the DisplayCutInWireframe parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.DisplayCutInWireframe

    @display_cut_in_wireframe.setter
    def display_cut_in_wireframe(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.DisplayCutInWireframe = value

    @property
    def grid_auto_filtering(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GridAutoFiltering() As boolean
                | 
                |     Returns or sets the GridAutoFiltering parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.GridAutoFiltering

    @grid_auto_filtering.setter
    def grid_auto_filtering(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.GridAutoFiltering = value

    @property
    def grid_auto_resize(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GridAutoResize() As boolean
                | 
                |     Returns or sets the GridAutoResize parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.GridAutoResize

    @grid_auto_resize.setter
    def grid_auto_resize(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.GridAutoResize = value

    @property
    def grid_height_step(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GridHeightStep() As float
                | 
                |     Returns or sets the GridHeightStep parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: float
        :rtype: float
        """

        return self.sectioning_setting_att.GridHeightStep

    @grid_height_step.setter
    def grid_height_step(self, value: float):
        """
        :param float value:
        """

        self.sectioning_setting_att.GridHeightStep = value

    @property
    def grid_position_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GridPositionMode() As CatGridPositionMode
                | 
                |     Returns or sets the GridPositionMode parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: int
        :rtype: int
        """

        return self.sectioning_setting_att.GridPositionMode

    @grid_position_mode.setter
    def grid_position_mode(self, value: int):
        """
        :param int value:
        """

        self.sectioning_setting_att.GridPositionMode = value

    @property
    def grid_style(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GridStyle() As CatSectionGridStyle
                | 
                |     Returns or sets the GridStyle parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: int
        :rtype: int
        """

        return self.sectioning_setting_att.GridStyle

    @grid_style.setter
    def grid_style(self, value: int):
        """
        :param int value:
        """

        self.sectioning_setting_att.GridStyle = value

    @property
    def grid_width_step(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GridWidthStep() As float
                | 
                |     Returns or sets the GridWidthStep parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: float
        :rtype: float
        """

        return self.sectioning_setting_att.GridWidthStep

    @grid_width_step.setter
    def grid_width_step(self, value: float):
        """
        :param float value:
        """

        self.sectioning_setting_att.GridWidthStep = value

    @property
    def hide_plane(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HidePlane() As boolean
                | 
                |     Returns or sets the HidePlane parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.HidePlane

    @hide_plane.setter
    def hide_plane(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.HidePlane = value

    @property
    def hide_result(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HideResult() As boolean
                | 
                |     Returns or sets the HideResult parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.HideResult

    @hide_result.setter
    def hide_result(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.HideResult = value

    @property
    def plane_normal(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PlaneNormal() As CatSectionPlaneNormal
                | 
                |     Returns or sets the PlaneNormal parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: int
        :rtype: int
        """

        return self.sectioning_setting_att.PlaneNormal

    @plane_normal.setter
    def plane_normal(self, value: int):
        """
        :param int value:
        """

        self.sectioning_setting_att.PlaneNormal = value

    @property
    def plane_origin(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PlaneOrigin() As CatSectionPlaneOrigin
                | 
                |     Returns or sets the PlaneOrigin parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: int
        :rtype: int
        """

        return self.sectioning_setting_att.PlaneOrigin

    @plane_origin.setter
    def plane_origin(self, value: int):
        """
        :param int value:
        """

        self.sectioning_setting_att.PlaneOrigin = value

    @property
    def section_export_type(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SectionExportType() As boolean
                | 
                |     Returns or sets the SectionExportType parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.SectionExportType

    @section_export_type.setter
    def section_export_type(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.SectionExportType = value

    @property
    def section_fill(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SectionFill() As boolean
                | 
                |     Returns or sets the SectionFill parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.SectionFill

    @section_fill.setter
    def section_fill(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.SectionFill = value

    @property
    def update_result(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property UpdateResult() As boolean
                | 
                |     Returns or sets the UpdateResult parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.UpdateResult

    @update_result.setter
    def update_result(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.UpdateResult = value

    @property
    def viewer_auto_open(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ViewerAutoOpen() As boolean
                | 
                |     Returns or sets the ViewerAutoOpen parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.ViewerAutoOpen

    @viewer_auto_open.setter
    def viewer_auto_open(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.ViewerAutoOpen = value

    @property
    def viewer_auto_reframe(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ViewerAutoReframe() As boolean
                | 
                |     Returns or sets the ViewerAutoReframe parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.ViewerAutoReframe

    @viewer_auto_reframe.setter
    def viewer_auto_reframe(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.ViewerAutoReframe = value

    @property
    def viewer_lock_2d(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ViewerLock2D() As boolean
                | 
                |     Returns or sets the ViewerLock2D parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: bool
        :rtype: bool
        """

        return self.sectioning_setting_att.ViewerLock2D

    @viewer_lock_2d.setter
    def viewer_lock_2d(self, value: bool):
        """
        :param bool value:
        """

        self.sectioning_setting_att.ViewerLock2D = value

    @property
    def window_default_height(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property WindowDefaultHeight() As long
                | 
                | 
                |     Role:Retrieve section window default height if the window open mode is
                |     catSecWindow_DefaultSize
                | 
                |     Parameters:
                | 
                |         oWindowDefaultHeight
                | 
                |     Returns:
                |         S_OK Successfully retieved the window open mode E_FAIL Failed to
                |         retrieved the window open mode

        :return: int
        :rtype: int
        """

        return self.sectioning_setting_att.WindowDefaultHeight

    @window_default_height.setter
    def window_default_height(self, value: int):
        """
        :param int value:
        """

        self.sectioning_setting_att.WindowDefaultHeight = value

    @property
    def window_default_width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property WindowDefaultWidth() As long
                | 
                | 
                |     Role:Retrieve section window default width if the window open mode is
                |     catSecWindow_DefaultSize
                | 
                |     Parameters:
                | 
                |         oWindowDefaultWidth
                | 
                |     Returns:
                |         S_OK Successfully retieved the window open mode E_FAIL Failed to
                |         retrieved the window open mode

        :return: int
        :rtype: int
        """

        return self.sectioning_setting_att.WindowDefaultWidth

    @window_default_width.setter
    def window_default_width(self, value: int):
        """
        :param int value:
        """

        self.sectioning_setting_att.WindowDefaultWidth = value

    @property
    def window_open_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property WindowOpenMode() As CatSecWindowOpenMode
                | 
                | 
                |     Role:Retrieve section window open mode
                | 
                |     Parameters:
                | 
                |         oWindowOpenMode
                |             Legal values:
                |             catSecWindow_DefaultSize :Opens the sectioning window(s) with the
                |             default size specified in the Tools->Options.
                |             catSecWindow_TileVertically :Tiles the sectioning window(s)
                |             vertically in the viewer 
                | 
                |     Returns:
                |         S_OK Successfully retieved the window open mode E_FAIL Failed to
                |         retrieved the window open mode

        :return: int
        :rtype: int
        """

        return self.sectioning_setting_att.WindowOpenMode

    @window_open_mode.setter
    def window_open_mode(self, value: int):
        """
        :param int value:
        """

        self.sectioning_setting_att.WindowOpenMode = value

    def get_clipping_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetClippingModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ClippingMode
                |     parameter.
                |     Role:Retrieves the state of the ClippingMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetClippingModeInfo(io_admin_level, io_locked)

    def get_display_cut_in_wireframe_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDisplayCutInWireframeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DisplayCutInWireframe
                |     parameter.
                |     Role:Retrieves the state of the DisplayCutInWireframe parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetDisplayCutInWireframeInfo(io_admin_level, io_locked)

    def get_grid_auto_filtering_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetGridAutoFilteringInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the GridAutoFiltering
                |     parameter.
                |     Role:Retrieves the state of the GridAutoFiltering parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetGridAutoFilteringInfo(io_admin_level, io_locked)

    def get_grid_auto_resize_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetGridAutoResizeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the GridAutoResize
                |     parameter.
                |     Role:Retrieves the state of the GridAutoResize parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetGridAutoResizeInfo(io_admin_level, io_locked)

    def get_grid_height_step_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetGridHeightStepInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the GridHeightStep
                |     parameter.
                |     Role:Retrieves the state of the GridHeightStep parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetGridHeightStepInfo(io_admin_level, io_locked)

    def get_grid_position_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetGridPositionModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the GridPositionMode
                |     parameter.
                |     Role:Retrieves the state of the GridPositionMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetGridPositionModeInfo(io_admin_level, io_locked)

    def get_grid_style_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetGridStyleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the GridStyle
                |     parameter.
                |     Role:Retrieves the state of the GridStyle parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetGridStyleInfo(io_admin_level, io_locked)

    def get_grid_width_step_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetGridWidthStepInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the GridWidthStep
                |     parameter.
                |     Role:Retrieves the state of the GridWidthStep parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetGridWidthStepInfo(io_admin_level, io_locked)

    def get_hide_plane_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetHidePlaneInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the HidePlane
                |     parameter.
                |     Role:Retrieves the state of the HidePlane parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetHidePlaneInfo(io_admin_level, io_locked)

    def get_hide_result_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetHideResultInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the HideResult
                |     parameter.
                |     Role:Retrieves the state of the HideResult parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetHideResultInfo(io_admin_level, io_locked)

    def get_plane_color(self, o_r: int, o_g: int, o_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPlaneColor(long oR,
                | long oG,
                | long oB)
                | 
                |     Returns the PlaneColor parameter.
                | 
                |     Parameters:
                | 
                |         oR
                |             the red component of the color. 
                |         oG
                |             the green component of the color. 
                |         oB
                |             the blue component of the color.
                | 
                |             Ensure consistency with the C++ interface to which the work is
                |             delegated.

        :param int o_r:
        :param int o_g:
        :param int o_b:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.GetPlaneColor(o_r, o_g, o_b)

    def get_plane_color_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPlaneColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PlaneColor
                |     parameter.
                |     Role:Retrieves the state of the PlaneColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetPlaneColorInfo(io_admin_level, io_locked)

    def get_plane_normal_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPlaneNormalInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PlaneNormal
                |     parameter.
                |     Role:Retrieves the state of the PlaneNormal parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetPlaneNormalInfo(io_admin_level, io_locked)

    def get_plane_origin_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPlaneOriginInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PlaneOrigin
                |     parameter.
                |     Role:Retrieves the state of the PlaneOrigin parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetPlaneOriginInfo(io_admin_level, io_locked)

    def get_section_export_type_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSectionExportTypeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SectionExportType
                |     parameter.
                |     Role:Retrieves the state of the SectionExportType parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetSectionExportTypeInfo(io_admin_level, io_locked)

    def get_section_fill_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSectionFillInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SectionFill
                |     parameter.
                |     Role:Retrieves the state of the SectionFill parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetSectionFillInfo(io_admin_level, io_locked)

    def get_update_result_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetUpdateResultInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UpdateResult
                |     parameter.
                |     Role:Retrieves the state of the UpdateResult parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetUpdateResultInfo(io_admin_level, io_locked)

    def get_viewer_auto_open_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetViewerAutoOpenInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ViewerAutoOpen
                |     parameter.
                |     Role:Retrieves the state of the ViewerAutoOpen parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetViewerAutoOpenInfo(io_admin_level, io_locked)

    def get_viewer_auto_reframe_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetViewerAutoReframeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ViewerAutoReframe
                |     parameter.
                |     Role:Retrieves the state of the ViewerAutoReframe parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetViewerAutoReframeInfo(io_admin_level, io_locked)

    def get_viewer_lock2_d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetViewerLock2DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ViewerLock2D
                |     parameter.
                |     Role:Retrieves the state of the ViewerLock2D parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetViewerLock2DInfo(io_admin_level, io_locked)

    def get_window_default_height_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetWindowDefaultHeightInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WindowDefaultHeight
                |     parameter.
                |     Role:Retrieves the state of the WindowDefaultHeight parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetWindowDefaultHeightInfo(io_admin_level, io_locked)

    def get_window_default_width_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetWindowDefaultWidthInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WindowDefaultWidth
                |     parameter.
                |     Role:Retrieves the state of the WindowDefaultWidth parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetWindowDefaultWidthInfo(io_admin_level, io_locked)

    def get_window_open_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetWindowOpenModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WindowOpenMode
                |     parameter.
                |     Role:Retrieves the state of the WindowOpenMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.sectioning_setting_att.GetWindowOpenModeInfo(io_admin_level, io_locked)

    def set_clipping_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetClippingModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ClippingMode parameter.
                |     Role:Locks or unlocks the PlaneOrigin parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetClippingModeLock(i_locked)

    def set_display_cut_in_wireframe_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDisplayCutInWireframeLock(boolean iLocked)
                | 
                |     Locks or unlocks the DisplayCutInWireframe parameter.
                |     Role:Locks or unlocks the DisplayCutInWireframe parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetDisplayCutInWireframeLock(i_locked)

    def set_grid_auto_filtering_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGridAutoFilteringLock(boolean iLocked)
                | 
                |     Locks or unlocks the GridAutoFiltering parameter.
                |     Role:Locks or unlocks the GridAutoFiltering parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetGridAutoFilteringLock(i_locked)

    def set_grid_auto_resize_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGridAutoResizeLock(boolean iLocked)
                | 
                |     Locks or unlocks the GridAutoResize parameter.
                |     Role:Locks or unlocks the GridAutoResize parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetGridAutoResizeLock(i_locked)

    def set_grid_height_step_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGridHeightStepLock(boolean iLocked)
                | 
                |     Locks or unlocks the GridHeightStep parameter.
                |     Role:Locks or unlocks the GridHeightStep parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetGridHeightStepLock(i_locked)

    def set_grid_position_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGridPositionModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the GridPositionMode parameter.
                |     Role:Locks or unlocks the GridPositionMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetGridPositionModeLock(i_locked)

    def set_grid_style_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGridStyleLock(boolean iLocked)
                | 
                |     Locks or unlocks the GridStyle parameter.
                |     Role:Locks or unlocks the GridStyle parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetGridStyleLock(i_locked)

    def set_grid_width_step_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGridWidthStepLock(boolean iLocked)
                | 
                |     Locks or unlocks the GridWidthStep parameter.
                |     Role:Locks or unlocks the GridWidthStep parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetGridWidthStepLock(i_locked)

    def set_hide_plane_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetHidePlaneLock(boolean iLocked)
                | 
                |     Locks or unlocks the HidePlane parameter.
                |     Role:Locks or unlocks the HidePlane parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetHidePlaneLock(i_locked)

    def set_hide_result_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetHideResultLock(boolean iLocked)
                | 
                |     Locks or unlocks the HideResult parameter.
                |     Role:Locks or unlocks the HideResult parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetHideResultLock(i_locked)

    def set_plane_color(self, i_r: int, i_g: int, i_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPlaneColor(long iR,
                | long iG,
                | long iB)
                | 
                |     Sets the PlaneColor parameter.
                | 
                |     Parameters:
                | 
                |         oR
                |             the red component of the color. 
                |         oG
                |             the green component of the color. 
                |         oB
                |             the blue component of the color.
                | 
                |             Ensure consistency with the C++ interface to which the work is
                |             delegated.

        :param int i_r:
        :param int i_g:
        :param int i_b:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetPlaneColor(i_r, i_g, i_b)

    def set_plane_color_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPlaneColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the PlaneColor parameter.
                |     Role:Locks or unlocks the PlaneColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetPlaneColorLock(i_locked)

    def set_plane_normal_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPlaneNormalLock(boolean iLocked)
                | 
                |     Locks or unlocks the PlaneNormal parameter.
                |     Role:Locks or unlocks the PlaneNormal parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetPlaneNormalLock(i_locked)

    def set_plane_origin_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPlaneOriginLock(boolean iLocked)
                | 
                |     Locks or unlocks the PlaneOrigin parameter.
                |     Role:Locks or unlocks the PlaneOrigin parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetPlaneOriginLock(i_locked)

    def set_section_export_type_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSectionExportTypeLock(boolean iLocked)
                | 
                |     Locks or unlocks the SectionExportType parameter.
                |     Role:Locks or unlocks the SectionExportType parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetSectionExportTypeLock(i_locked)

    def set_section_fill_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSectionFillLock(boolean iLocked)
                | 
                |     Locks or unlocks the SectionFill parameter.
                |     Role:Locks or unlocks the SectionFill parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetSectionFillLock(i_locked)

    def set_update_result_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetUpdateResultLock(boolean iLocked)
                | 
                |     Locks or unlocks the UpdateResult parameter.
                |     Role:Locks or unlocks the UpdateResult parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetUpdateResultLock(i_locked)

    def set_viewer_auto_open_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetViewerAutoOpenLock(boolean iLocked)
                | 
                |     Locks or unlocks the ViewerAutoOpen parameter.
                |     Role:Locks or unlocks the ViewerAutoOpen parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetViewerAutoOpenLock(i_locked)

    def set_viewer_auto_reframe_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetViewerAutoReframeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ViewerAutoReframe parameter.
                |     Role:Locks or unlocks the ViewerAutoReframe parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetViewerAutoReframeLock(i_locked)

    def set_viewer_lock2_d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetViewerLock2DLock(boolean iLocked)
                | 
                |     Locks or unlocks the ViewerLock2D parameter.
                |     Role:Locks or unlocks the ViewerLock2D parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetViewerLock2DLock(i_locked)

    def set_window_default_height_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetWindowDefaultHeightLock(boolean iLocked)
                | 
                |     Locks or unlocks the WindowDefaultHeight parameter.
                |     Role:Locks or unlocks the WindowDefaultHeight parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetWindowDefaultHeightLock(i_locked)

    def set_window_default_width_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetWindowDefaultWidthLock(boolean iLocked)
                | 
                |     Locks or unlocks the WindowDefaultWidth parameter.
                |     Role:Locks or unlocks the WindowDefaultWidth parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetWindowDefaultWidthLock(i_locked)

    def set_window_open_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetWindowOpenModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the WindowOpenMode parameter.
                |     Role:Locks or unlocks the WindowOpenMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.sectioning_setting_att.SetWindowOpenModeLock(i_locked)

    def __repr__(self):
        return f'SectioningSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.in_interfaces.printer import Printer
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Printers(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Printers
                | 
                | A collection of all the Printer objects managed by the
                | application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Printer)
        self.printers = com_object

    def item(self, i_index: cat_variant) -> Printer:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As Printer
                | 
                |     Returns a printer using its index or its device name from the Printers
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the printer to retrieve from the
                |             collection of printers. As a numerics, this index is the rank of the printer in
                |             the collection. The index of the first printer in the collection is 1, and the
                |             index of the last printer is Count. As a string, it is the DeviceName of the
                |             printer. 
                | 
                |     Returns:
                |         The retrieved printer 
                |     Example:
                |         This example returns in ThisPrinter the third printer in the
                |         collection, and in ThatPrinter the printer named
                |         LaserPrinter.
                | 
                |          Dim ThisPrinter As Printer
                |          Set ThisPrinter = CATIA.Printers.Item(3)
                |          Dim ThatPrinter As Printer
                |          Set ThatPrinter = CATIA.Printers.Item("LaserPrinter")

        :param cat_variant i_index:
        :return: Printer
        :rtype: Printer
        """
        return Printer(self.printers.Item(i_index))

    def __getitem__(self, n: int) -> Printer:
        if (n + 1) > self.count:
            raise StopIteration

        return Printer(self.printers.item(n + 1))

    def __iter__(self) -> Iterator[Printer]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Printers(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.funct_associations import FunctAssociations
from pycatia.funct_system_interfaces.functional_facet import FunctionalFacet


class FunctMultiRepMgr(FunctionalFacet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATFunctSystemItf.FunctionalFacet
                |                         FunctMultiRepMgr
                | 
                | The interface to access a Functional Multi-Rep manager.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.funct_multi_rep_mgr = com_object

    @property
    def associations(self) -> FunctAssociations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Associations() As FunctAssociations (Read Only)
                | 
                |     Get the Associations collection.

        :return: FunctAssociations
        :rtype: FunctAssociations
        """

        return FunctAssociations(self.funct_multi_rep_mgr.Associations)

    @property
    def current_assoc(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CurrentAssoc() As long
                | 
                |     Get the CurrentAssoc.

        :return: int
        :rtype: int
        """

        return self.funct_multi_rep_mgr.CurrentAssoc

    @current_assoc.setter
    def current_assoc(self, value: int):
        """
        :param int value:
        """

        self.funct_multi_rep_mgr.CurrentAssoc = value

    def __repr__(self):
        return f'FunctMultiRepMgr(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DrawingPicture(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingPicture
                | 
                | Represents a drawing picture in a drawing view.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_picture = com_object

    @property
    def crop_bottom(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property cropBottom() As double
                | 
                |     Returns or sets the cropBottom of the drawing picture. The cropBottom is
                |     the size of the margin on the bottom of the picture. The cropBottom, like any
                |     length, is measured in millimeters.
                | 
                |     Example:
                |         This example sets the cropBottom of the MyPicture drawing picture to 10
                |         mm
                | 
                |          MyPicture.cropBottom = 10.

        :return: float
        :rtype: float
        """

        return self.drawing_picture.cropBottom

    @crop_bottom.setter
    def crop_bottom(self, value: float):
        """
        :param float value:
        """

        self.drawing_picture.cropBottom = value

    @property
    def crop_left(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property cropLeft() As double
                | 
                |     Returns or sets the cropLeft of the drawing picture. The cropLeft is the
                |     size of the margin on the left of the picture. The cropLeft, like any length,
                |     is measured in millimeters.
                | 
                |     Example:
                |         This example sets the cropLeft of the MyPicture drawing picture to 10
                |         mm
                | 
                |          MyPicture.cropLeft = 10.

        :return: float
        :rtype: float
        """

        return self.drawing_picture.cropLeft

    @crop_left.setter
    def crop_left(self, value: float):
        """
        :param float value:
        """

        self.drawing_picture.cropLeft = value

    @property
    def crop_right(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property cropRight() As double
                | 
                |     Returns or sets the cropRight of the drawing picture. The cropRight is the
                |     size of the margin on the right of the picture. The cropRight, like any length,
                |     is measured in millimeters.
                | 
                |     Example:
                |         This example sets the cropRight of the MyPicture drawing picture to 10
                |         mm
                | 
                |          MyPicture.cropRight = 10.

        :return: float
        :rtype: float
        """

        return self.drawing_picture.cropRight

    @crop_right.setter
    def crop_right(self, value: float):
        """
        :param float value:
        """

        self.drawing_picture.cropRight = value

    @property
    def crop_top(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property cropTop() As double
                | 
                |     Returns or sets the cropTop of the drawing picture. The cropTop is the size
                |     of the margin on the top of the picture. The cropTop, like any length, is
                |     measured in millimeters.
                | 
                |     Example:
                |         This example sets the cropTop of the MyPicture drawing picture to 10
                |         mm
                | 
                |          MyPicture.cropTop = 10.

        :return: float
        :rtype: float
        """

        return self.drawing_picture.cropTop

    @crop_top.setter
    def crop_top(self, value: float):
        """
        :param float value:
        """

        self.drawing_picture.cropTop = value

    @property
    def format(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property format() As CatPictureFormat
                | 
                |     Sets the picture format.
                | 
                |     Parameters:
                | 
                |         iPictureFormat
                |             Compression format. 
                | 
                |     Returns:
                | 
                |         Legal values:
                | 
                |         S_OK
                |             Method correctly executed. 
                |         E_FAIL
                |             Method execution failed. 
                |             Reasons of the failure are not given. 
                |         E_IMPL
                |             No implementation available for this method. 
                | 
                |     See also:
                |         CatPictureFormat

        :return: int
        :rtype: int
        """

        return self.drawing_picture.format

    @format.setter
    def format(self, value: int):
        """
        :param int value:
        """

        self.drawing_picture.format = value

    @property
    def height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property height() As double
                | 
                |     Returns or sets the height of the drawing picture. The height, like any
                |     length, is measured in millimeters.
                | 
                |     Example:
                |         This example gets the height of the MyPicture drawing
                |         picture
                | 
                |          Height = MyPicture.height

        :return: float
        :rtype: float
        """

        return self.drawing_picture.height

    @height.setter
    def height(self, value: float):
        """
        :param float value:
        """

        self.drawing_picture.height = value

    @property
    def ratio_lock(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ratioLock() As boolean
                | 
                |     Returns or sets the ratioLock of the drawing picture. The ratioLock is a
                |     boolean value If ratioLock is True it means that the size must not be changed
                |     by command in a interactive session.But it does not avoid size modifications
                |     thru VBScript exec (height and width still available for
                |     modification).
                | 
                |     Example:
                |         This example sets the ratioLock of the MyPicture drawing picture to
                |         True
                | 
                |          MyPicture.ratioLock = True

        :return: bool
        :rtype: bool
        """

        return self.drawing_picture.ratioLock

    @ratio_lock.setter
    def ratio_lock(self, value: bool):
        """
        :param bool value:
        """

        self.drawing_picture.ratioLock = value

    @property
    def width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property width() As double
                | 
                |     Returns or sets the width of the drawing picture. The width, like any
                |     length, is measured in millimeters.
                | 
                |     Example:
                |         This example gets the width of the MyPicture drawing
                |         picture
                | 
                |          Width = MyPicture.width

        :return: float
        :rtype: float
        """

        return self.drawing_picture.width

    @width.setter
    def width(self, value: float):
        """
        :param float value:
        """

        self.drawing_picture.width = value

    @property
    def x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property x() As double
                | 
                |     Returns or sets the x coordinate of the drawing picture position. It is
                |     expressed with respect to the view coordinate system. This coordinate, like any
                |     length, is measured in millimeters.
                | 
                |     Example:
                |         This example sets the x coordinate of the position of the MyPicture
                |         drawing picture to 5 inches. You need first to convert the 5 inches into
                |         millimeters.
                | 
                |          NewXCoordinate = 5*25.4
                |          MyPicture.x =  NewXCoordinate

        :return: float
        :rtype: float
        """

        return self.drawing_picture.x

    @x.setter
    def x(self, value: float):
        """
        :param float value:
        """

        self.drawing_picture.x = value

    @property
    def y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property y() As double
                | 
                |     Returns or sets the y coordinate of the drawing picture position. It is
                |     expressed with respect to the view coordinate system. This coordinate, like any
                |     length, is measured in millimeters.
                | 
                |     Example:
                |         This example sets the y coordinate of the position of the MyPicture
                |         drawing picture to 5 inches. You need first to convert the 5 inches into
                |         millimeters.
                | 
                |          NewYCoordinate = 5*25.4
                |          MyPicture.y =  NewYCoordinate

        :return: float
        :rtype: float
        """

        return self.drawing_picture.y

    @y.setter
    def y(self, value: float):
        """
        :param float value:
        """

        self.drawing_picture.y = value

    def get_original_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetOriginalHeight() As double
                | 
                |     Gets the original height of the drawing picture. The height, like any
                |     length, is measured in millimeters.
                | 
                |     Example:
                |         This example gets the original height of the MyPicture drawing
                |         picture
                | 
                |          Height = MyPicture.GetOriginalHeight()

        :return: float
        :rtype: float
        """
        return self.drawing_picture.GetOriginalHeight()

    def get_original_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetOriginalWidth() As double
                | 
                |     Gets the original width of the drawing picture. The width, like any length,
                |     is measured in millimeters.
                | 
                |     Example:
                |         This example gets the original width of the MyPicture drawing
                |         picture
                | 
                |          Width = MyPicture.GetOriginalWidth()

        :return: float
        :rtype: float
        """
        return self.drawing_picture.GetOriginalWidth()

    def __repr__(self):
        return f'DrawingPicture(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeSpine(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeSpine
                | 
                | Represents the hybrid spine curve feature object.
                | Role:Use the CATIAHybridShapeFactory to create a HybridShapeSpine
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_spine = com_object

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Gets or Sets the orientation. Orientation by reference with the normal to
                |     the first section/plane

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_spine.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_spine.Orientation = value

    @property
    def start_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property StartPoint() As Reference
                | 
                |     Returns or sets the start point of the spine.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_spine.StartPoint)

    @start_point.setter
    def start_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_spine.StartPoint = reference_point.com_object

    def add_guide(self, i_guide: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddGuide(Reference iGuide)
                | 
                |     Adds a guide to the spine curve.
                | 
                |     Parameters:
                | 
                |         iGuide
                |             The guide curve to be added

        :param Reference i_guide:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.AddGuide(i_guide.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_guide'
        # # vba_code = """
        # # Public Function add_guide(hybrid_shape_spine)
        # #     Dim iGuide (2)
        # #     hybrid_shape_spine.AddGuide iGuide
        # #     add_guide = iGuide
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_section(self, i_section: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddSection(Reference iSection)
                | 
                |     Adds a section or a plane to the spine curve.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section curve or plane to be added
                | 
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): PlanarFace.

        :param Reference i_section:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.AddSection(i_section.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_section'
        # # vba_code = """
        # # Public Function add_section(hybrid_shape_spine)
        # #     Dim iSection (2)
        # #     hybrid_shape_spine.AddSection iSection
        # #     add_section = iSection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_guide(self, i_idx: int, op_ia_guide: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetGuide(long iIdx,
                | Reference opIAGuide)
                | 
                |     Retrieves a guide .
                | 
                |     Parameters:
                | 
                |         iIdx
                |             The index of the guide 
                |         opIAGuide
                |             The guide retrieved

        :param int i_idx:
        :param Reference op_ia_guide:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.GetGuide(i_idx, op_ia_guide.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_guide'
        # # vba_code = """
        # # Public Function get_guide(hybrid_shape_spine)
        # #     Dim iIdx (2)
        # #     hybrid_shape_spine.GetGuide iIdx
        # #     get_guide = iIdx
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_number_of_guides(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNumberOfGuides() As long
                | 
                |     Retrieves number of guides in a spine curve.
                | 
                |     Parameters:
                | 
                |         oNbGuides
                |             Number of guides in a spine curve

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_spine.GetNumberOfGuides()

    def get_number_of_sections(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNumberOfSections() As long
                | 
                |     Retrieves number of sections in a spine curve.
                | 
                |     Parameters:
                | 
                |         oNbSections
                |             Number of sections in a spine curve

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_spine.GetNumberOfSections()

    def get_section(self, i_idx: int, o_section: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSection(long iIdx,
                | Reference oSection)
                | 
                |     Retrieves a section or a plane.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             The index of the section 
                |         oSection
                |             The section retrieved

        :param int i_idx:
        :param Reference o_section:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.GetSection(i_idx, o_section.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_section'
        # # vba_code = """
        # # Public Function get_section(hybrid_shape_spine)
        # #     Dim iIdx (2)
        # #     hybrid_shape_spine.GetSection iIdx
        # #     get_section = iIdx
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def modify_guide_curve(self, ip_ia_guide: Reference, ip_ia_new_guide: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ModifyGuideCurve(Reference ipIAGuide,
                | Reference ipIANewGuide)
                | 
                |     Modifies a guide from the spine curve.
                | 
                |     Parameters:
                | 
                |         ipIAGuide
                |             The guide curve to be replaced. 
                |         ipIANewGuide
                |             The new guide curve or plane which replaces the old
                |             one.

        :param Reference ip_ia_guide:
        :param Reference ip_ia_new_guide:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.ModifyGuideCurve(ip_ia_guide.com_object, ip_ia_new_guide.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'modify_guide_curve'
        # # vba_code = """
        # # Public Function modify_guide_curve(hybrid_shape_spine)
        # #     Dim ipIAGuide (2)
        # #     hybrid_shape_spine.ModifyGuideCurve ipIAGuide
        # #     modify_guide_curve = ipIAGuide
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def modify_section_curve(self, ip_ia_section: Reference, ip_ia_new_section: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ModifySectionCurve(Reference ipIASection,
                | Reference ipIANewSection)
                | 
                |     Modifies a section or a plane from the spine curve.
                | 
                |     Parameters:
                | 
                |         ipIASection
                |             The section curve or plane to be replaced. 
                |         ipIANewSection
                |             The new section curve or plane which replaces the old
                |             one.

        :param Reference ip_ia_section:
        :param Reference ip_ia_new_section:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.ModifySectionCurve(ip_ia_section.com_object, ip_ia_new_section.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'modify_section_curve'
        # # vba_code = """
        # # Public Function modify_section_curve(hybrid_shape_spine)
        # #     Dim ipIASection (2)
        # #     hybrid_shape_spine.ModifySectionCurve ipIASection
        # #     modify_section_curve = ipIASection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_guide(self, i_guide: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveGuide(Reference iGuide)
                | 
                |     Removes a guide from the spine curve.
                | 
                |     Parameters:
                | 
                |         iGuide
                |             The guide curve to be removed.

        :param Reference i_guide:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.RemoveGuide(i_guide.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_guide'
        # # vba_code = """
        # # Public Function remove_guide(hybrid_shape_spine)
        # #     Dim iGuide (2)
        # #     hybrid_shape_spine.RemoveGuide iGuide
        # #     remove_guide = iGuide
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_section(self, i_section: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveSection(Reference iSection)
                | 
                |     Removes a section or a plane from the spine curve.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section curve or plane to be removed.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): PlanarFace.

        :param Reference i_section:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.RemoveSection(i_section.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_section'
        # # vba_code = """
        # # Public Function remove_section(hybrid_shape_spine)
        # #     Dim iSection (2)
        # #     hybrid_shape_spine.RemoveSection iSection
        # #     remove_section = iSection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_start_point(self, i_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetStartPoint(Reference iPoint)
                | 
                |     Sets the start point of the spine curve.
                | 
                |     Parameters:
                | 
                |         iPoint
                |             The point to be set as the spine curve start
                |             point.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): Vertex.

        :param Reference i_point:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_spine.SetStartPoint(i_point.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_start_point'
        # # vba_code = """
        # # Public Function set_start_point(hybrid_shape_spine)
        # #     Dim iPoint (2)
        # #     hybrid_shape_spine.SetStartPoint iPoint
        # #     set_start_point = iPoint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeSpine(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING, Tuple

from pycatia.drafting_interfaces.drawing_arrows import DrawingArrows
from pycatia.drafting_interfaces.drawing_components import DrawingComponents
from pycatia.drafting_interfaces.drawing_dimensions import DrawingDimensions
from pycatia.drafting_interfaces.drawing_pictures import DrawingPictures
from pycatia.drafting_interfaces.drawing_tables import DrawingTables
from pycatia.drafting_interfaces.drawing_texts import DrawingTexts
from pycatia.drafting_interfaces.drawing_threads import DrawingThreads
from pycatia.drafting_interfaces.drawing_view_generative_behavior import DrawingViewGenerativeBehavior
from pycatia.drafting_interfaces.drawing_view_generative_links import DrawingViewGenerativeLinks
from pycatia.drafting_interfaces.drawing_weldings import DrawingWeldings
from pycatia.mec_mod_interfaces.geometric_elements import GeometricElements
from pycatia.sketcher_interfaces.factory_2D import Factory2D
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.drafting_interfaces.drawing_text import DrawingText


class DrawingView(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingView
                | 
                | Represents a drawing view in a drawing sheet.
                | 
                | The drawing view is included in a drawing sheet and contains texts,leaders,
                | dimensions, arrows, pictures, tables, 2D Geometry and 2D
                | component.
                | Warning: This interface is not available with 2D Layout for 3D
                | Design.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_view = com_object

    @property
    def angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Angle() As double
                | 
                |     Returns or sets the angle of the drawing view. The angle is measured
                |     between the axis system of the drawing view and the axis system of the drawing
                |     sheet where the drawing view lies. The angle is measured in radians and is
                |     counted counterclockwise.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example sets the angle of the MyView drawing view to 90 degrees
                |         clockwise. You first need to compute the angle in radians and set the minus
                |         sign to indicate the rotation is clockwise.
                | 
                |          PI = 3.1415926535
                |          Angle90Clockwise = -PI/2
                |          MyView.Angle = Angle90Clockwise

        :return: float
        :rtype: float
        """

        return self.drawing_view.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.drawing_view.Angle = value

    @property
    def arrows(self) -> DrawingArrows:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Arrows() As DrawingArrows (Read Only)
                | 
                |     Returns the drawing arrow collection of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in ArrowCollection the collection of arrows of
                |         the MyView drawing view.
                | 
                |          Dim ArrowCollection As DrawingArrows
                |          Set ArrowCollection = MyView.Arrows

        :return: DrawingArrows
        :rtype: DrawingArrows
        """

        return DrawingArrows(self.drawing_view.Arrows)

    @property
    def components(self) -> DrawingComponents:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Components() As DrawingComponents (Read Only)
                | 
                |     Returns the drawing component instances collection (i.e. ditto collection)
                |     of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in ComponentCollection the collection of
                |         component instances of the MyView drawing view.
                | 
                |          Dim ComponentCollection As DrawingComponents
                |          Set ComponentCollection = MyView.Components

        :return: DrawingComponents
        :rtype: DrawingComponents
        """

        return DrawingComponents(self.drawing_view.Components)

    @property
    def dimensions(self) -> DrawingDimensions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Dimensions() As DrawingDimensions (Read Only)
                | 
                |     Returns the drawing dimension collection of the drawing
                |     view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in DimensionCollection the collection of
                |         dimensions of the MyView drawing view.
                | 
                |          Dim DimensionCollection As DrawingDimensions
                |          Set DimensionCollection = MyView.Dimensions

        :return: DrawingDimensions
        :rtype: DrawingDimensions
        """

        return DrawingDimensions(self.drawing_view.Dimensions)

    @property
    def factory_2d(self) -> Factory2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Factory2D() As Factory2D (Read Only)
                | 
                |     Returns the 2D factory of the drawing view. Take care that you must open
                |     edition on a sketch before adding or modifying elements in it. Take care that
                |     you must close edition on a sketch to keep all modifications before saving
                |     document.
                |     Warning: This method is not available with 2D Layout for 3D Design. To get
                |     Sketch from factory2D:
                | 
                |       Set mySketch = my2DFactory.GetParent
                |      
                | 
                |     Example:
                |         The following example returns in my2DFactory the 2D
                |         factory
                |         of the view myView:
                | 
                |          Set my2DFactory = myView.Factory2D

        :return: Factory2D
        :rtype: Factory2D
        """

        return Factory2D(self.drawing_view.Factory2D)

    @property
    def frame_visualization(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property FrameVisualization() As boolean
                | 
                |     Returns or sets the drawing view frame visualization
                |     state.
                |     True if the drawing view frame is visible.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example shows the frame of the MyView drawing
                |         view.
                | 
                |          MyView.FrameVisualization = True

        :return: bool
        :rtype: bool
        """

        return self.drawing_view.FrameVisualization

    @frame_visualization.setter
    def frame_visualization(self, value: bool):
        """
        :param bool value:
        """

        self.drawing_view.FrameVisualization = value

    @property
    def generative_behavior(self) -> DrawingViewGenerativeBehavior:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property GenerativeBehavior() As DrawingViewGenerativeBehavior (Read
                | Only)
                | 
                |     Returns the generative behavior of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in MyViewGenBehavior the generative behavior of
                |         the MyView drawing view.
                | 
                |          Dim MyViewGenBehavior As
                |          DrawingViewGenerativeBehavior
                |          Set MyViewGenBehavior = MyView.GenerativeBehavior

        :return: DrawingViewGenerativeBehavior
        :rtype: DrawingViewGenerativeBehavior
        """

        return DrawingViewGenerativeBehavior(self.drawing_view.GenerativeBehavior)

    @property
    def generative_links(self) -> DrawingViewGenerativeLinks:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property GenerativeLinks() As DrawingViewGenerativeLinks (Read
                | Only)
                | 
                |     Returns the generative links of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in MyViewGenLinks the generative links of the
                |         MyView drawing view.
                | 
                |          Dim MyViewGenLinks As DrawingViewGenerativeLinks
                |          Set MyViewGenLinks = MyView.GenerativeLinks

        :return: DrawingViewGenerativeLinks
        :rtype: DrawingViewGenerativeLinks
        """

        return DrawingViewGenerativeLinks(self.drawing_view.GenerativeLinks)

    @property
    def geometric_elements(self) -> GeometricElements:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property GeometricElements() As GeometricElements (Read
                | Only)
                | 
                |     Returns the collection of geometric elements included in the drawing view
                |     sketch.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         The following example returns in colGeometry the list of geometric
                |         elements in the view myView:
                | 
                |          Dim colGeometry As GeometricElements
                |          Set colGeometry = myView.GeometricElements

        :return: GeometricElements
        :rtype: GeometricElements
        """

        return GeometricElements(self.drawing_view.GeometricElements)

    @property
    def lock_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property LockStatus() As boolean
                | 
                |     Returns or sets the lock status of a drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                |     precondition: This property does not exist for the detail view. In this
                |     case, the method returns failed.
                | 
                |     Example:
                |         This example locks the ViewToWorkOn drawing view.
                | 
                |          ViewToWorkOn.LockStatus = True

        :return: bool
        :rtype: bool
        """

        return self.drawing_view.LockStatus

    @lock_status.setter
    def lock_status(self, value: bool):
        """
        :param bool value:
        """

        self.drawing_view.LockStatus = value

    @property
    def pictures(self) -> DrawingPictures:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Pictures() As DrawingPictures (Read Only)
                | 
                |     Returns the drawing picture collection of the drawing
                |     view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in PictureCollection the collection of pictures
                |         of the MyView drawing view.
                | 
                |          Dim PictureCollection As DrawingPictures
                |          Set PictureCollection = MyView.Pictures

        :return: DrawingPictures
        :rtype: DrawingPictures
        """

        return DrawingPictures(self.drawing_view.Pictures)

    @property
    def reference_view(self) -> 'DrawingView':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ReferenceView() As DrawingView
                | 
                |     Returns or sets the reference view. The reference view is also the parent
                |     view to which the current drawing view is linked and which is used as reference
                |     for alignment. Generally, the reference view is the front view, and the other
                |     views, such as the top, bottom, left, and right views, are linked to it. This
                |     reference drawing view is used:
                | 
                |         When moving the current drawing view. Its location remains constrained
                |         to the reference view, depending on its type. For example, a left view can move
                |         horizontally and a top view can move vertically.
                |         To update the scale of the current drawing view according to the
                |         modification performed to the one of the reference drawing
                |         view.
                | 
                | 
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in ReferenceView the view used as reference by
                |         the MyView drawing view.
                | 
                |          Dim ReferenceView As DrawingView
                |          Set ReferenceView = MyView.RefView

        :return: DrawingView
        :rtype: DrawingView
        """

        return DrawingView(self.drawing_view.ReferenceView)

    @reference_view.setter
    def reference_view(self, value: 'DrawingView'):
        """
        :param DrawingView value:
        """

        self.drawing_view.ReferenceView = value

    @property
    def scale(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Scale() As double
                | 
                |     Returns or sets the scale of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example sets the scale of the MyView drawing view to
                |         0.5.
                | 
                |          MyView.Scale = 0.5

        :return: float
        :rtype: float
        """

        return self.drawing_view.Scale

    @scale.setter
    def scale(self, value: float):
        """
        :param float value:
        """

        self.drawing_view.Scale = value

    @property
    def scale2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Scale2() As double
                | 
                |     Returns or sets the scale of the drawing view (Workaround for VBA
                |     keyword).
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example sets the scale of the MyView drawing view to
                |         0.5.
                | 
                |          MyView.Scale2 = 0.5

        :return: float
        :rtype: float
        """

        return self.drawing_view.Scale2

    @scale2.setter
    def scale2(self, value: float):
        """
        :param float value:
        """

        self.drawing_view.Scale2 = value

    @property
    def tables(self) -> DrawingTables:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Tables() As DrawingTables (Read Only)
                | 
                |     Returns the drawing table collection of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in TextCollection the collection of texts of the
                |         MyView drawing view.
                | 
                |          Dim TableCollection As DrawingTables
                |          Set TableCollection = MyView.Tables

        :return: DrawingTables
        :rtype: DrawingTables
        """

        return DrawingTables(self.drawing_view.Tables)

    @property
    def texts(self) -> DrawingTexts:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Texts() As DrawingTexts (Read Only)
                | 
                |     Returns the drawing text collection of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in TextCollection the collection of texts of the
                |         MyView drawing view.
                | 
                |          Dim TextCollection As DrawingTexts
                |          Set TextCollection = MyView.Texts

        :return: DrawingTexts
        :rtype: DrawingTexts
        """

        return DrawingTexts(self.drawing_view.Texts)

    @property
    def threads(self) -> DrawingThreads:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Threads() As DrawingThreads (Read Only)
                | 
                |     Returns the drawing thread collection of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in ThreadCollection the collection of threads of
                |         the MyView drawing view.
                | 
                |          Dim ThreadCollection As DrawingThreads
                |          Set ThreadCollection = MyView.Threads

        :return: DrawingThreads
        :rtype: DrawingThreads
        """

        return DrawingThreads(self.drawing_view.Threads)

    @property
    def view_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ViewType() As CatDrawingViewType (Read Only)
                | 
                |     Returns the drawing view type.
                |     Warning: This method is not available with 2D Layout for 3D Design.

        :return: int
        :rtype: int
        """

        return self.drawing_view.ViewType

    @property
    def weldings(self) -> DrawingWeldings:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Weldings() As DrawingWeldings (Read Only)
                | 
                |     Returns the drawing welding collection of the drawing
                |     view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves in weldingCollection the collection of weldings
                |         of the MyView drawing view.
                | 
                |          Dim weldingCollection As DrawingWeldings
                |          Set weldingCollection = MyView.Weldings

        :return: DrawingWeldings
        :rtype: DrawingWeldings
        """

        return DrawingWeldings(self.drawing_view.Weldings)

    @property
    def x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property x() As double
                | 
                |     For an interactive view, get_x and put_x methods are equivalents to
                |     get_xAxisData, put_xAxisData In a generative case, get_x. put_x returns or sets
                |     the x coordinate of the projection of the 3D centre of gravity. It is expressed
                |     with respect to the sheet coordinate system. This coordinate, like any length,
                |     is measured in millimeters.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves the x coordinate of the view relative position
                |         MyView.
                | 
                |          X = MyView.x

        :return: float
        :rtype: float
        """

        return self.drawing_view.x

    @x.setter
    def x(self, value: float):
        """
        :param float value:
        """

        self.drawing_view.x = value

    @property
    def x_axis_data(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property xAxisData() As double
                | 
                |     Returns or sets the x coordinate of the drawing view coordinate system
                |     origin. It is expressed with respect to the sheet coordinate system. This
                |     coordinate, like any length, is measured in millimeters.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example retrieves the x coordinate of the coordinate system origin
                |         of the MyView drawing view.
                | 
                |          X = MyView.xAxisData

        :return: float
        :rtype: float
        """

        return self.drawing_view.xAxisData

    @x_axis_data.setter
    def x_axis_data(self, value: float):
        """
        :param float value:
        """

        self.drawing_view.xAxisData = value

    @property
    def y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property y() As double
                | 
                |     For an interactive view, get_y and put_y methods are equivalents to
                |     get_yAxisData, put_yAxisData In a generative case, get_y. put_y returns or sets
                |     the y coordinate of the projection of the 3D centre of gravity. It is expressed
                |     with respect to the sheet coordinate system. This coordinate, like any length,
                |     is measured in millimeters.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example sets the y coordinate of the view relative position MyView
                |         to 5 inches. You need first to convert the 5 inches into
                |         millimeters.
                | 
                |          NewYCoordinate = 5*25.4
                |          MyView.y = NewYCoordinate

        :return: float
        :rtype: float
        """

        return self.drawing_view.y

    @y.setter
    def y(self, value: float):
        """
        :param float value:
        """

        self.drawing_view.y = value

    @property
    def y_axis_data(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property yAxisData() As double
                | 
                |     Returns or sets the y coordinate of the drawing view coordinate system
                |     origin. It is expressed with respect to the sheet coordinate system. This
                |     coordinate, like any length, is measured in millimeters.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example sets the y coordinate of the coordinate system origin of
                |         the MyView drawing view to 5 inches. You need first to convert the 5 inches
                |         into millimeters.
                | 
                |          NewYCoordinate = 5*25.4
                |          MyView.yAxisData = NewYCoordinate

        :return: float
        :rtype: float
        """

        return self.drawing_view.yAxisData

    @y_axis_data.setter
    def y_axis_data(self, value: float):
        """
        :param float value:
        """

        self.drawing_view.yAxisData = value

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Activate()
                | 
                |     Activates the drawing view. Activating a drawing view means that this
                |     drawing view is the one on which the end-user is now
                |     working.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example activates the ViewToWorkOn drawing view.
                | 
                |          ViewToWorkOn.Activate()

        :return: None
        :rtype: None
        """
        return self.drawing_view.Activate()

    def aligned_with_reference_view(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub AlignedWithReferenceView()
                | 
                |     Activates the alignment with the reference view. Activating the alignment
                |     with the reference view restores the constraints that the reference view
                |     imposes to the current drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example activates the alignment from the MyView drawing view to
                |         its reference view.
                | 
                |          MyView.AlignedWithReferenceView()

        :return: None
        :rtype: None
        """
        return self.drawing_view.AlignedWithReferenceView()

    def get_view_name(self, i_view_name_prefix: str, i_view_name_ident: str, i_view_name_suffix: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetViewName(CATBSTR iViewNamePrefix,
                | CATBSTR iViewNameIdent,
                | CATBSTR iViewNameSuffix)
                | 
                |     Returns the prefix, the ident and the suffix of the name of the drawing
                |     view. The method returns an error in case of 2D component
                |     reference.
                |     Note: Prefix of drawing view can be also retrieved across name property
                |     defined in CATIABase
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                | 
                |           This example gets the prefix, the ident, and the suffix of the name
                |           
                |          of the MyView drawing view
                |          
                | 
                |          Dim MyPrefix, MyIdent, MySuffix As CATBSTR
                |          MyView.GetViewName (MyPrefix, MyIdent, MySuffix)

        :param str i_view_name_prefix:
        :param str i_view_name_ident:
        :param str i_view_name_suffix:
        :return: None
        :rtype: None
        """
        return self.drawing_view.GetViewName(i_view_name_prefix, i_view_name_ident, i_view_name_suffix)

    def insert_view_angle(self, i_first: int, io_text: 'DrawingText') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub InsertViewAngle(long iFirst,
                | DrawingText ioText)
                | 
                |     Insert the Angle parameter in the text of the drawing
                |     text.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Parameters:
                | 
                |         iFirst
                |             The first character from which the parameter is inserted
                |             
                |         ioText
                |             The text on wich the scale parameter will be inserted
                |             
                |         Example:
                |             This example insert the Angle parameter of MyView drawing view at
                |             the end of MyText drawing text.
                | 
                | 
                |              index = Len(MyText.Text)+1
                |              MyView.InsertViewScale index, MyText

        :param int i_first:
        :param DrawingText io_text:
        :return: None
        :rtype: None
        """
        return self.drawing_view.InsertViewAngle(i_first, io_text.com_object)

    def insert_view_scale(self, i_first: int, io_text: 'DrawingText') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub InsertViewScale(long iFirst,
                | DrawingText ioText)
                | 
                |     Insert the scale parameter in the text of the drawing
                |     text.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Parameters:
                | 
                |         iFirst
                |             The first character from which the parameter is inserted
                |             
                |         ioText
                |             The text on wich the scale parameter will be inserted
                |             
                |         Example:
                |             This example insert the Scale parameter of MyView drawing view at
                |             the first character of MyText drawing text.
                | 
                | 
                |              MyView.InsertViewScale 1, MyText

        :param int i_first:
        :param DrawingText io_text:
        :return: None
        :rtype: None
        """
        return self.drawing_view.InsertViewScale(i_first, io_text.com_object)

    def is_generative(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func IsGenerative() As boolean
                | 
                |     Returns whether the drawing view has a generative
                |     behavior.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                |     True if the drawing view has a generative behavior.
                | 
                |     Example:
                |         This example retrieves in GenView if the MyView drawing view has a
                |         generative behavior property set.
                | 
                |          GenView = MyView.IsGenerative()

        :return: bool
        :rtype: bool
        """
        return self.drawing_view.IsGenerative()

    def isolate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Isolate()
                | 
                |     Isolates the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example isolates the MyView drawing view.
                | 
                |          MyView.Isolate

        :return: None
        :rtype: None
        """
        return self.drawing_view.Isolate()

    def save_edition(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SaveEdition()
                | 
                |     Saves the Sketch Edition. Once you have finished working with the drawing
                |     view, you must save its edition in order to register modification for
                |     UNDO/REDO. Indeed when activating a view, this view is open in edition while
                |     the previous active view is closed in edition. So calling SaveEdition() before
                |     exiting a macro without changing active view will allow a correct UNDO/REDO
                |     behavior.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         The following example saves the edition of the drawing view
                |         MyView:
                | 
                |          MyView.SaveEdition

        :return: None
        :rtype: None
        """
        return self.drawing_view.SaveEdition()

    def set_view_name(self, i_view_name_prefix: str, i_view_name_ident: str, i_view_name_suffix: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetViewName(CATBSTR iViewNamePrefix,
                | CATBSTR iViewNameIdent,
                | CATBSTR iViewNameSuffix)
                | 
                |     Sets the prefix, the ident and the suffix of the name of the drawing view.
                |     The method returns an error in case of 2D component
                |     reference.
                |     Note: Prefix of drawing view can be also modified across name property
                |     defined in CATIABase
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                | 
                |           This example sets the prefix, the ident, and the suffix of the name
                |           
                |          of the MyView drawing view respectively to "MyPrefix",
                |          "MyIdent",
                |          and "MySuffix".
                |          
                | 
                |          MyView.SetViewName ("MyPrefix", "MyIdent",
                |          "MySuffix")

        :param str i_view_name_prefix:
        :param str i_view_name_ident:
        :param str i_view_name_suffix:
        :return: None
        :rtype: None
        """
        return self.drawing_view.SetViewName(i_view_name_prefix, i_view_name_ident, i_view_name_suffix)

    def size(self) -> Tuple[float, float, float, float]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Size(CATSafeArrayVariant oValues)
                |
                |     Returns the bounding box of the drawing view.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                |
                |     Parameters:
                |
                |         oValues
                |             The values of the view bounding box: Xmin, Xmax, Ymin, Ymax
                |
                |
                |     Example:
                |
                |
                |
                |              This example gets the bounding box of the ViewToWorkOn drawing
                |              view.
                |
                |
                |              Dim oXY(4) As Double
                |              ViewToWorkOn.Size oXY
                |              Xmin = oXY(0)
                |              Xmax = oXY(1)
                |              Ymin = oXY(2)
                |              Ymax = oXY(3)

        :param tuple o_values:
        :return: Double
        :rtype: Double
        """
        vba_function_name = "size"
        vba_code = """
        Public Function size(drawing_view)
            Dim oXY(4)
            drawing_view.Size oXY
            size = oXY
        End Function
        """

        system_service = self.application.system_service
        value = system_service.evaluate(
            vba_code, 0, vba_function_name, [self.com_object]
        )

        # we don't return value directly as CATIA returns for example
        # "(-15.0, 30.0, -15.0, 30.0, None)" I don't know what the additional
        # value None at the end represents.
        return value[0], value[1], value[2], value[3]

    def un_aligned_with_reference_view(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub UnAlignedWithReferenceView()
                | 
                |     Deactivates the alignment with the reference view. Deactivating the
                |     alignment to the reference view removes the constraints that the reference view
                |     imposes to the current drawing view. You can then, for example, move and
                |     position it freely.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         This example deactivates the alignment from the MyView drawing view to
                |         its reference view.
                | 
                |          MyView.UnAlignedWithReferenceView()

        :return: None
        :rtype: None
        """
        return self.drawing_view.UnAlignedWithReferenceView()

    def __repr__(self):
        return f'DrawingView(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.factory import Factory
from pycatia.system_interfaces.any_object import AnyObject


class InstanceFactory(Factory):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Factory
                |                         InstanceFactory
                | 
                | Represents the CATIAInstanceFactory.
                | Role: This interface is used to create a new instance of a shape reference
                | (ShapeInstance ) or a hybrid shape reference ( HybridShapeInstance ) in case of
                | the instantiation of a User Feature.
                | It is also used to instantiate a Power Copy reference.
                | 
                | This interface contains two protocols of instantiation:
                | 
                |     The first protocol is dedicated to User Feature instantiation
                |     only.
                |     It is defined by a single method: AddInstance . It creates a shape or
                |     hybrid shape instance depending on the result of the User
                |     Feature.
                |     Use this method when you want to perform only one instantiation of the
                |     reference. Read the document containing the User Feature reference and
                |     instantiate it.
                |     As the document containing the reference is released from the session at
                |     the end of the instantiation, it is not recommmended to use this method if you
                |     want to perform several instantiations of the same reference in a
                |     loop.
                |     In that case, prefer the second protocol of instantiation.
                |     The second protocol is dedicated to both User Feature and Power Copy
                |     instantiations.
                |     It is defined by several methods that must be called in
                |     order.
                |         For User Feature instantiation, these methods are an alternative way of
                |         the AddInstance method.
                |         It is recommended to use the second protocol to perform several
                |         instantiations of the same reference in a loop.
                |         For Power Copy instantiation, it is the only way of instantiating a
                |         reference.
                |     The instantiation process is composed of three major
                |     steps:
                |         The first step BeginInstanceFactory consists in initializing the
                |         InstanceFactory with the reference and the document where it is
                |         stored.
                |         This step must be called once at the beginning whatever the number of
                |         instantiations are done.
                |         Optional step InstantiationMode allow the user to specify the mode of
                |         the instantiation, that is to say "After" or "Inside".
                |         If this method is not called, the instantiation mode will be chosen
                |         according to the BeginInstantiate method.
                |         The second step is the instantiation itself: it is composed of five
                |         methods that must be called in the order.
                |         This set of five methods can be called in a loop in order to make
                |         several instantiations.
                |             The method BeginInstantiate is used to initialize all data of the
                |             reference.
                |             The method PutInputData is used to set a value to any input of the
                |             reference.
                |             The method GetParameter is used to retrieve any parameter of the
                |             reference in order to modify its value.
                |             The method Instantiate is used to duplicate the reference. It
                |             returns the created instance when it does exist.
                |             The method EndInstantiate is used to indicate that the
                |             instantiation is done.
                |         The third step EndInstanceFactory consists in ending the instantiation
                |         and cleaning the InstanceFactory.
                |         When doing several instantiations in a loop, this step must be called
                |         just once at the end of all instantiations.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.instance_factory = com_object

    @property
    def instantiation_mode(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InstantiationMode(CATBSTR iInstantiationModeBSTR) (Write
                | Only)
                | 
                |     Sets the mode of instantiation to "Inside" or "After".
                |     Role: This method should be called BEFORE the method BeginInstantiate to
                |     take into account the desired instantiation mode.
                |     It is used to set the destination path of insertion of the template
                |     reference.
                | 
                |     Example:
                |         The following example shows how to determine the instantiation mode
                |         (Mode's value is "Inside" or "After"):
                | 
                |          InstanceFactory.InstantationMode = Mode

        :return: str
        :rtype: str
        """

        return self.instance_factory.InstantiationMode

    @instantiation_mode.setter
    def instantiation_mode(self, value: str):
        """
        :param str value:
        """

        self.instance_factory.InstantiationMode = value

    def add_instance(self, i_reference: AnyObject) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func AddInstance(AnyObject iReference) As AnyObject
                | 
                |     Creates a new instance of a shape or hybrid shape.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The reference shape or hybrid shape. 
                | 
                |     Example:
                |         This example creates the instance NewInstance in the
                |         part.
                | 
                |          Set NewInstance = instanceFactory.AddInstance(reference)

        :param AnyObject i_reference:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.instance_factory.AddInstance(i_reference.com_object))

    def begin_instance_factory(self, i_name_of_reference: str, i_name_of_document: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub BeginInstanceFactory(CATBSTR iNameOfReference,
                | CATBSTR iNameOfDocument)
                | 
                |     Initializes the instantiation process with the document containing the
                |     reference.
                |     Role: Use this method to start instantiating a reference in the current
                |     document.
                |     In that method, the document containing the reference is locked in
                |     session.
                |     It will be unlocked in the last step EndInstanceFactory .
                | 
                |     Parameters:
                | 
                |         iNameOfReference
                |             The name of the reference to be instantiated. 
                |         iDocumentFileName
                |             The name of the file containing the document where to find the
                |             reference to be instantiated. 
                | 
                |     Example:
                |         The following example initializes the factory with a document and a
                |         reference:
                | 
                |         InstanceFactory.BeginInstanceFactory"NameOfReference","c:\\tmp\\NameOfDocument.CATPart"

        :param str i_name_of_reference:
        :param str i_name_of_document:
        :return: None
        :rtype: None
        """
        return self.instance_factory.BeginInstanceFactory(i_name_of_reference, i_name_of_document)

    def begin_instantiate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub BeginInstantiate()
                | 
                |     Initializes the data of the reference.
                |     Role: This is the first method of the second step of
                |     instantiation.
                |     It is used to initialize all data of the reference in the
                |     factory.
                | 
                |     Example:
                |         The following example shows how to initialize the
                |         factory:
                | 
                |          InstanceFactory.BeginInstantiate

        :return: None
        :rtype: None
        """
        return self.instance_factory.BeginInstantiate()

    def end_instance_factory(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub EndInstanceFactory()
                | 
                |     Ends the instantiation process.
                |     Role: Use this method to end the instantiation process.
                |     In that method the document containing the reference is unlocked and
                |     released from the session.
                | 
                |     Example:
                |         The following example shows how to end the
                |         instantiation:
                | 
                |          InstanceFactory.EndInstanceFactory

        :return: None
        :rtype: None
        """
        return self.instance_factory.EndInstanceFactory()

    def end_instantiate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub EndInstantiate()
                | 
                |     Ends the instantiation of the reference.
                |     Role: This is the fifth and last method of the second step of
                |     instantiation.
                |     It is used to end the instantiation: after this step, all the links to the
                |     reference are broken.
                | 
                |     Example:
                |         The following example shows how to end the
                |         instantiation:
                | 
                |          InstanceFactory.EndInstantiate

        :return: None
        :rtype: None
        """
        return self.instance_factory.EndInstantiate()

    def get_parameter(self, i_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetParameter(CATBSTR iName) As AnyObject
                | 
                |     Retrieves a parameter of the reference by its name.
                |     Role: This is the third method of the second step of
                |     instantiation.
                |     This step is optional.
                |     It is used to retrieve a parameter of the reference in order to change its
                |     value, using the ValuateFromString method of the Parameter
                |     interface.
                |     It has to be called on each parameter whose value has to be
                |     changed.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the parameter. 
                | 
                |     Example:
                |         The following example retrieves a parameter on the
                |         reference:
                | 
                |          Set parameter = InstanceFactory.GetParameter("Parameter1")

        :param str i_name:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.instance_factory.GetParameter(i_name))

    def instantiate(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Instantiate() As AnyObject
                | 
                |     Instantiates the reference in the current document.
                |     Role: This is the fourth method of the second step of
                |     instantiation.
                |     It is used to duplicate or instantiate the data of the
                |     reference.
                | 
                |         In case of Power Copy instantiation, the data are duplicated and there
                |         is no created instance.
                |         In case of User Feature instantiation, the data are instantiated and an
                |         instance is created and returned.
                | 
                |     Example:
                |         The following example instantiates the reference:
                | 
                |          Set Instance = InstanceFactory.Instantiate

        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.instance_factory.Instantiate())

    def put_input_data(self, i_name: str, i_input: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutInputData(CATBSTR iName,
                | CATBaseDispatch iInput)
                | 
                |     Sets a value to an input of the reference.
                |     Role: This is the second method of the second step of
                |     instantiation.
                |     It is used to set a value to any input of the reference.
                |     It has to be called on each input of the reference.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the input. 
                |         iInput
                |             The element to set as the new value of the input.
                |             All types of 
                | 
                |         Boundary object are possibly supported. 
                | 
                | Example:
                |     The following example sets a value to an input of the reference: The input
                |     is a point and its name is Input1.
                | 
                |      InstanceFactory.PutInputData "Input1",point1

        :param str i_name:
        :param AnyObject i_input:
        :return: None
        :rtype: None
        """
        return self.instance_factory.PutInputData(i_name, i_input.com_object)

    def __repr__(self):
        return f'InstanceFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
from pycatia.mec_mod_interfaces.shape import Shape


class Symmetry(Shape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         Symmetry
                | 
                | Represents the shape symmetry feature object.
                | This solid feature is created from an underlying HybridShapeSymmetry aggregated
                | by the Symmetry. Role: To access the data of the symmetry shape feature object.
                | The data includes:
                | 
                |     The element to be transformed
                |     The reference element which can be a point, a line or a
                |     plane
                | 
                | Use the CATIAShapeFactory to create ShapeFeature object.
                | 
                | See also:
                |     ShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.symmetry = com_object

    @property
    def hybrid_shape(self) -> HybridShape:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HybridShape() As HybridShape (Read Only)
                | 
                |     Gets the underlying HybridShapeSymmetry.
                | 
                |     Example:
                |         The following example explains how to retrieve the underlying
                |         HybridShape Symmetry
                | 
                |           Dim oHybridShape as AnyObject
                |           Set oHybridShape=oSymmetry.HybridShape
                |           oHybridShape.SectionCoupling = 2

        :return: HybridShape
        :rtype: HybridShape
        """

        return HybridShape(self.symmetry.HybridShape)

    def __repr__(self):
        return f'Symmetry(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pathlib import Path

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.product_structure_interfaces.product import Product


class AssemblyConvertor(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AssemblyConvertor
                | 
                | Product conversion object.
                | The AssemblyConvertor is the object that allows saving an
                | assembly to a specified format. Two objects exist from now on
                | : BillOfMaterial, which creates a bill of material (every
                | sub-assembly is represented, with all the one level depth
                | components), and ListingReport, which creates a listing report
                | (shows the product structure as it appears in the graph)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_convertor = com_object

    def print(self, i_file_type: str, i_file: Path, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Print(CATBSTR iFileType,
                | CATBSTR iFile,
                | Product iProduct)
                | 
                |     Extracts the product's contents as a specified format. Saves it in a txt,
                |     html or xls file (depends of the object).
                | 
                |     Parameters:
                | 
                |         iFileType
                |             Type of the resulting file : TXT (for text file),
                |             HTML (for html file), XLS (for xls file) or MOTIF
                |             (do not use).
                |         iFile
                |             Path of the resulting file 
                |         iProduct
                |             Product that will be converted

        :param str i_file_type:
        :param Path i_file:
        :param Product i_product:
        :return: None
        :rtype: None
        """

        vba_function_name = 'print'
        vba_code = """
        Public Function print(assembly_convertor, i_file_type, i_file, i_product)
            assembly_convertor.Print i_file_type, i_file, i_product
            print = iFileType
        End Function
        """
        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_file_type, str(i_file), i_product.com_object])

    def set_current_format(self, ilist_props: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetCurrentFormat(CATSafeArrayVariant ilistProps)
                | 
                |     Defines the properties that will be used in the print
                |     method.
                | 
                |     Parameters:
                | 
                |         ilistProps
                |             list of properties to display

        :param tuple ilist_props:
        :return: None
        :rtype: None
        """
        return self.assembly_convertor.SetCurrentFormat(ilist_props)

    def set_secondary_format(self, ilist_props: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetSecondaryFormat(CATSafeArrayVariant ilistProps)
                | 
                |     Defines the secondary properties that will be used in the print
                |     method.
                | 
                |     Parameters:
                | 
                |         ilistProps
                |             secondary list of properties to display

        :param tuple ilist_props:
        :return: None
        :rtype: None
        """
        return self.assembly_convertor.SetSecondaryFormat(ilist_props)

    def __repr__(self):
        return f'AssemblyConvertor(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SelectionSets(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SelectionSets
                | 
                | Interface to manage the Selection Sets in a document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.selection_sets = com_object

    def add_cso_into_selection_set(self, i_sel_set_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddCSOIntoSelectionSet(CATBSTR iSelSetName)
                | 
                |     Adds CSO's content in a Selection Set.
                | 
                |     Parameters:
                | 
                |         iSelSetName
                |             The name of the Selection Set in wich the CSO has to be added.
                |             
                | 
                |     Returns:
                |         The error code of function :
                | 
                |             S_OK if the content of the CSO is added
                |             E_FAIL if the content of the CSO is not added

        :param str i_sel_set_name:
        :return: None
        :rtype: None
        """
        return self.selection_sets.AddCSOIntoSelectionSet(i_sel_set_name)

    def create_selection_set(self, i_sel_set_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub CreateSelectionSet(CATBSTR iSelSetName)
                | 
                |     Creates a new Selection Set.
                |     Role: This method creates a new Selection Set.
                | 
                |     Parameters:
                | 
                |         iSelSetName
                |             The name of Selection Set to create. 
                | 
                |     Returns:
                |         The error code of function :
                | 
                |             S_OK if the Selection Set is created
                |             E_FAIL if a problem occurred

        :param str i_sel_set_name:
        :return: None
        :rtype: None
        """
        return self.selection_sets.CreateSelectionSet(i_sel_set_name)

    def delete_selection_set(self, i_sel_set_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub DeleteSelectionSet(CATBSTR iSelSetName)
                | 
                |     Deletes a Selection Set.
                |     Role: This method removes a Selection Set and all its
                |     content.
                | 
                |     Parameters:
                | 
                |         iSelSetName
                |             The Selection Set to delete. 
                | 
                |     Returns:
                |         The error code of function :
                | 
                |             S_OK if the method succeeded
                |             E_FAIL if a problem occurred

        :param str i_sel_set_name:
        :return: None
        :rtype: None
        """
        return self.selection_sets.DeleteSelectionSet(i_sel_set_name)

    def get_list_of_selection_set(self, o_list_of_selection_set: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetListOfSelectionSet(CATSafeArrayVariant
                | oListOfSelectionSet)
                | 
                |     Retrieves the list of Selection Sets in the document.
                | 
                |     Parameters:
                | 
                |         oListOfSelectionSet
                |             The list of Selection Sets in the document 
                | 
                |     Returns:
                |         The error code of function :
                | 
                |             S_OK if the method succeeded
                |             E_FAIL if an error occurred

        :param tuple o_list_of_selection_set:
        :return: None
        :rtype: None
        """
        return self.selection_sets.GetListOfSelectionSet(o_list_of_selection_set)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_selection_set'
        # # vba_code = """
        # # Public Function get_list_of_selection_set(selection_sets)
        # #     Dim oListOfSelectionSet (2)
        # #     selection_sets.GetListOfSelectionSet oListOfSelectionSet
        # #     get_list_of_selection_set = oListOfSelectionSet
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_selection_set_into_cso(self, i_sel_set_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutSelectionSetIntoCSO(CATBSTR iSelSetName)
                | 
                |     Puts Selection Set's content in the CSO.
                | 
                |     Parameters:
                | 
                |         iSelSetName
                |             The name of the Selection Set to put in the CSO. 
                | 
                |     Returns:
                |         The error code of function :
                | 
                |             S_OK if the content of the Selection Set is added in the
                |             CSO
                |             E_FAIL if the content of the Selection Set is added in the
                |             CSO

        :param str i_sel_set_name:
        :return: None
        :rtype: None
        """
        return self.selection_sets.PutSelectionSetIntoCSO(i_sel_set_name)

    def rename_selection_set(self, i_old_sel_set_name: str, i_new_sel_set_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RenameSelectionSet(CATBSTR iOldSelSetName,
                | CATBSTR iNewSelSetName)
                | 
                |     Renames a Selection Set.
                | 
                |     Parameters:
                | 
                |         iOldSelSetName
                |             The original name of the Selection Set. 
                |         iNewSelSetName
                |             The new name of the Selection Set. 
                | 
                |     Returns:
                |         The error code of function :
                | 
                |             S_OK if the name is changed
                |             E_FAIL if the name is not changed

        :param str i_old_sel_set_name:
        :param str i_new_sel_set_name:
        :return: None
        :rtype: None
        """
        return self.selection_sets.RenameSelectionSet(i_old_sel_set_name, i_new_sel_set_name)

    def __repr__(self):
        return f'SelectionSets(name="{ self.name }")'
